@@ -142,8 +142,10 @@ class Paperless:
     def _create_base_url(url: str | URL) -> URL:
         """Create URL from string or URL and prepare for further use."""
         # reverse compatibility, fall back to https
-        if isinstance(url, str) and "://" not in url:
-            url = f"https://{url}".rstrip("/")
+        if isinstance(url, str):
+            if "://" not in url:
+                url = f"https://{url}"
+            url = url.rstrip("/")
         url = URL(url)
 
         # scheme check. fall back to https
@@ -243,10 +245,11 @@ class Paperless:
             try:
                 async with self.request("get", API_PATH["api_schema"]) as res:
                     res.raise_for_status()
+                    self._version = res.headers.get("x-version", None)
+                    await res.read()
             except aiohttp.ClientError:
                 return False
 
-            self._version = res.headers.get("x-version", None)
             return True
 
         async def _init_with_legacy_response() -> dict[str, str]:
@@ -305,7 +308,7 @@ class Paperless:
         form: dict[str, Any] | None = None,
         params: dict[str, Any] | None = None,
         **kwargs: Any,
-    ) -> AsyncGenerator[aiohttp.ClientResponse, None]:
+    ) -> AsyncGenerator[aiohttp.ClientResponse]:
         """Send a request to the Paperless api and return the `aiohttp.ClientResponse`.
 
         This method provides a little interface for utilizing `aiohttp.FormData`.
