@@ -14,8 +14,10 @@ from .models.custom_fields import CustomFieldHelper  # noqa: F401
 from .models.documents import DocumentHelper, DocumentMetaHelper, DocumentNoteHelper  # noqa: F401
 from .models.mails import MailAccountHelper, MailRuleHelper  # noqa: F401
 from .models.permissions import GroupHelper, UserHelper  # noqa: F401
+from .models.remote_version import RemoteVersionHelper  # noqa: F401
 from .models.saved_views import SavedViewHelper  # noqa: F401
 from .models.share_links import ShareLinkHelper  # noqa: F401
+from .models.statistics import StatisticHelper  # noqa: F401
 from .models.status import StatusHelper  # noqa: F401
 from .models.tasks import TaskHelper  # noqa: F401
 from .models.workflows import WorkflowHelper  # noqa: F401
