@@ -22,8 +22,10 @@ from .documents import (
 from .mails import MailAccount, MailRule
 from .pages import Page
 from .permissions import Group, User
+from .remote_version import RemoteVersion
 from .saved_views import SavedView
 from .share_links import ShareLink, ShareLinkDraft
+from .statistics import Statistic
 from .status import Status
 from .tasks import Task
 from .workflows import Workflow, WorkflowAction, WorkflowTrigger
@@ -45,9 +47,11 @@ __all__ = (
     "MailAccount",
     "MailRule",
     "Page",
+    "RemoteVersion",
     "SavedView",
     "ShareLink",
     "ShareLinkDraft",
+    "Statistic",
     "Status",
     "StoragePath",
     "StoragePathDraft",
