@@ -136,11 +136,14 @@ class Document(
     created_date: datetime.date | None = None
     modified: datetime.datetime | None = None
     added: datetime.datetime | None = None
+    deleted_at: datetime.datetime | None = None
     archive_serial_number: int | None = None
     original_file_name: str | None = None
     archived_file_name: str | None = None
     is_shared_by_requester: bool | None = None
     custom_fields: DocumentCustomFieldList | None = None
+    page_count: int | None = None
+    mime_type: str | None = None
     __search_hit__: DocumentSearchHitType | None = None
 
     def __init__(self, api: "Paperless", data: dict[str, Any]) -> None:
@@ -707,7 +710,7 @@ class DocumentHelper(
             except Exception as exc:
                 raise AsnRequestError from exc
 
-    async def more_like(self, pk: int) -> AsyncGenerator[Document, None]:
+    async def more_like(self, pk: int) -> AsyncGenerator[Document]:
         """Lookup documents similar to the given document pk.
 
         Shortcut function. Same behaviour is possible using `reduce()`.
@@ -718,7 +721,7 @@ class DocumentHelper(
             async for item in self:
                 yield item
 
-    async def search(self, query: str) -> AsyncGenerator[Document, None]:
+    async def search(self, query: str) -> AsyncGenerator[Document]:
         """Lookup documents by a search query.
 
         Shortcut function. Same behaviour is possible using `reduce()`.
