@@ -31,6 +31,7 @@ from pypaperless.models.common import (
     DocumentMetadataType,
     DocumentSearchHitType,
     RetrieveFileMode,
+    StatisticDocumentFileTypeCount,
     StatusDatabaseType,
     StatusStorageType,
     StatusTasksType,
@@ -381,6 +382,42 @@ class TestModelDocuments:
         assert item.custom_fields.default(-1337) is None
 
 
+# test models/remote_version.py
+class TestModelVersion:
+    """Version test cases."""
+
+    async def test_call(self, resp: aioresponses, api_latest: Paperless) -> None:
+        """Test call."""
+        resp.get(
+            f"{PAPERLESS_TEST_URL}{API_PATH['remote_version']}",
+            status=200,
+            payload=PATCHWORK["remote_version"],
+        )
+        remote_version = await api_latest.remote_version()
+        assert remote_version
+        assert isinstance(remote_version.version, str)
+        assert isinstance(remote_version.update_available, bool)
+
+
+# test models/statistics.py
+class TestModelStatistics:
+    """Statistics test cases."""
+
+    async def test_call(self, resp: aioresponses, api_latest: Paperless) -> None:
+        """Test call."""
+        resp.get(
+            f"{PAPERLESS_TEST_URL}{API_PATH['statistics']}",
+            status=200,
+            payload=PATCHWORK["statistics"],
+        )
+        stats = await api_latest.statistics()
+        assert stats
+        assert isinstance(stats.character_count, int)
+        assert isinstance(stats.document_file_type_counts, list)
+        for item in stats.document_file_type_counts:
+            assert isinstance(item, StatisticDocumentFileTypeCount)
+
+
 # test models/status.py
 class TestModelStatus:
     """Status test cases."""
